Prepare for SoC rework of ARM code:
- rename CONFIG_BOOTBINFUNC into  CONFIG_INIT_CRITICAL
- rename memsetup into lowlevel_init (function name and source files)
diff --git a/cpu/sa1100/start.S b/cpu/sa1100/start.S
index 7974344..08e41c7 100644
--- a/cpu/sa1100/start.S
+++ b/cpu/sa1100/start.S
@@ -213,10 +213,10 @@
 	/*
 	 * before relocating, we have to setup RAM timing
 	 * because memory timing is board-dependend, you will
 	 * find a memsetup.S in your board directory.
 	 */
 	mov	ip,	lr
-	bl	memsetup
+	bl	lowlevel_init
 	mov	lr,	ip
 
 	/*
@@ -213,10 +213,10 @@
 	 * before relocating, we have to setup RAM timing
 	 * because memory timing is board-dependend, you will
-	 * find a memsetup.S in your board directory.
+	 * find a lowlevel_init.S in your board directory.
 	 */
 	mov	ip,	lr